%global nhgamedir /usr/games/nethack
%global nhdatadir /var/games/nethack

%global fontfamily nethack-bitmap
%global fonts *.pcf
%global _myfontname nethack-bitmap

Name:           nethack
Version:        3.6.6
Release:        %mkrel 4
Summary:        A rogue-like single player dungeon exploration game

Group:          Games/Adventure
License:        NGPL
URL:            https://nethack.org
Source0:        https://nethack.org/download/%{version}/%{name}-366-src.tgz
Source1:        %{name}.desktop
Patch0:         %{name}-3.6.2-makefile.patch
Patch1:         %{name}-3.6.2-config.patch
Patch2:         Makefile.top.patch
Patch3:         %{name}-3.6.6-guidebook.patch
Requires:       %{_myfontname}-fonts-core

BuildRequires:  bdftopcf
BuildRequires:  bison
BuildRequires:  desktop-file-utils
BuildRequires:  flex
BuildRequires:  fontpackages-devel
BuildRequires:  gcc
BuildRequires:  mkfontdir
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)


%description
NetHack is a single player dungeon exploration game that runs on a
wide variety of computer systems, with a variety of graphical and text
interfaces all using the same game engine.

Unlike many other Dungeons & Dragons-inspired games, the emphasis in
NetHack is on discovering the detail of the dungeon and not simply
killing everything in sight - in fact, killing everything in sight is
a good way to die quickly.

Each game presents a different landscape - the random number generator
provides an essentially unlimited number of variations of the dungeon
and its denizens to be discovered by the player in one of a number of
characters: you can pick your race, your role, and your gender.


%package -n %{_myfontname}-fonts
Summary:        Bitmap fonts for Nethack
Group:          System/Fonts/X11 bitmap
BuildArch:      noarch
Requires:       fontpackages-filesystem

%description -n %{_myfontname}-fonts
Bitmap fonts for Nethack.

%package -n %{_myfontname}-fonts-core
Summary:         X11 core fonts configuration for %{name}
Group:          System/Fonts/X11 bitmap
BuildArch:      noarch
Requires:        %{_myfontname}-fonts
Requires(post):  %{_myfontname}-fonts
Requires(post):  coreutils
Requires(post):  mkfontdir
Requires(preun): coreutils


%description -n %{_myfontname}-fonts-core
X11 core fonts configuration for %{_myfontname}.


%prep
%setup -q -c -n nethack-3.6.6
cd NetHack-NetHack-3.6.6_Released
mv * ..
cd ..
rm -rf NetHack-NetHack-3.6.6_Released
%patch0 -p0 -b .makefile
%patch1 -p0 -b .config
%patch2 -p0 -b .MAK2
%patch3 -p0 -b .guidebook

%{__sed} -i -e "s:PREFIX=\$(wildcard ~)/nh/install:PREFIX=/usr:" sys/unix/hints/linux
%{__sed} -i -e "s:^\(HACKDIR=\).*:\1%{nhgamedir}:" sys/unix/hints/linux
sh sys/unix/setup.sh sys/unix/hints/linux

# Set our paths
%{__sed} -i -e "s:^\(HACKDIR=\).*:\1%{nhgamedir}:" sys/unix/nethack.sh
%{__sed} -i -e "s:FEDORA_CONFDIR:%{nhgamedir}:" sys/unix/nethack.sh
%{__sed} -i -e "s:FEDORA_STATEDIR:%{nhdatadir}:" include/unixconf.h
%{__sed} -i -e "s:FEDORA_HACKDIR:%{nhgamedir}:" include/config.h
%{__sed} -i -e "s:/usr/games/lib/nethackdir:%{nhgamedir}:" \
        doc/nethack.6 doc/nethack.txt doc/recover.6 doc/recover.txt

# Point the linker in the right direction
%{__sed} -i -e "s:-L/usr/X11R6/lib:-L/usr/X11R6/%{_lib}:" \
        src/Makefile util/Makefile

%build
make all

%install
rm -rf $RPM_BUILD_ROOT
%make_install \
        PREFIX=$RPM_BUILD_ROOT \
        HACKDIR=$RPM_BUILD_ROOT%{nhgamedir} \
        GAMEDIR=$RPM_BUILD_ROOT%{nhgamedir} \
        VARDIR=$RPM_BUILD_ROOT%{nhdatadir} \
        SHELLDIR=$RPM_BUILD_ROOT%{_bindir} \
        CHOWN=/bin/true \
        CHGRP=/bin/true

install -d -m 0755 $RPM_BUILD_ROOT%{_mandir}/man6
make -C doc MANDIR=$RPM_BUILD_ROOT%{_mandir}/man6 manpages

install -D -p -m 0644 win/X11/nh_icon.xpm \
        $RPM_BUILD_ROOT%{_datadir}/pixmaps/nethack.xpm

desktop-file-install \
        --dir $RPM_BUILD_ROOT%{_datadir}/applications \
        --add-category Game \
        --add-category RolePlaying \
        %{SOURCE1}

# Install the fonts for the X11 interface
cd win/X11
bdftopcf -o nh10.pcf nh10.bdf
bdftopcf -o ibm.pcf ibm.bdf
%fontinstall
# install -m 0755 -d $RPM_BUILD_ROOT%{_fontdir}
# install -m 0644 -p *.pcf $RPM_BUILD_ROOT%{_fontdir}

%{__sed} -i -e 's:^!\(NetHack.tile_file.*\):\1:' \
        $RPM_BUILD_ROOT%{nhgamedir}/NetHack.ad

%post -n %{_myfontname}-fonts-core
mkfontdir %{_fontdir}
if [ ! -L /etc/X11/fontpath.d/nethack ] ; then
    ln -s %{_fontdir} /etc/X11/fontpath.d/nethack
fi

%preun -n %{_myfontname}-fonts-core
if [ $1 -eq 0 ] ; then
    rm /etc/X11/fontpath.d/nethack
    rm %{_fontdir}/fonts.dir
fi;


%files
%doc doc/*.txt README dat/license dat/history
%doc dat/opthelp dat/wizhelp
%{_mandir}/man6/*
%{_datadir}/pixmaps/nethack.xpm
%{_datadir}/applications/nethack.desktop
%{_bindir}/nethack
# %%{nhgamedir}
%defattr(0664,root,games)
%config(noreplace) %{nhdatadir}/record
%config(noreplace) %{nhdatadir}/perm
%config(noreplace) %{nhdatadir}/logfile
%config(noreplace) %{nhdatadir}/xlogfile
%attr(0775,root,games) %dir %{nhdatadir}
%attr(0775,root,games) %dir %{nhdatadir}/save
%attr(2755,root,games) %{nhgamedir}/nethack
%config(noreplace) %{nhgamedir}/nhdat
%config(noreplace) %{nhgamedir}/sysconf
%config(noreplace) %{nhgamedir}/NetHack.ad
%config(noreplace) %{nhgamedir}/license
%config(noreplace) %{nhgamedir}/pet_mark.xbm
%config(noreplace) %attr(0555,root,games) %{nhgamedir}/recover
%config(noreplace) %{nhgamedir}/rip.xpm
%config(noreplace) %{nhgamedir}/pilemark.xbm
%config(noreplace) %{nhgamedir}/symbols
%config(noreplace) %{nhgamedir}/x11tiles

# %%_font_pkg -n bitmap *.pcf
%fontfiles

%files -n %{_myfontname}-fonts-core



%changelog
* Sat Aug 01 2020 tv <tv> 3.6.6-4.mga8
+ Revision: 1610414
- fix unexpanded-macro Summary
+ shlomif <shlomif>
- fonts macro updates+move to core/release

* Wed Jul 22 2020 shlomif <shlomif> 3.6.6-3.mga8
+ Revision: 1607790
- Fix install deps

* Wed Jul 22 2020 shlomif <shlomif> 3.6.6-2.mga8
+ Revision: 1607782
- Sync patches and .spec from fedora. Experimental.

* Fri Mar 20 2020 daviddavid <daviddavid> 3.6.6-1.mga8
+ Revision: 1558157
- new version: 3.6.6, fixes CVE-2020-5254 (mga#26228)

* Thu Feb 20 2020 umeabot <umeabot> 3.6.5-2.mga8
+ Revision: 1547334
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 shlomif <shlomif> 3.6.5-1.mga8
+ Revision: 1487880
- New version 3.6.5

* Thu Dec 26 2019 shlomif <shlomif> 3.6.4-1.mga8
+ Revision: 1470155
- New version 3.6.4

* Sun Jun 30 2019 shlomif <shlomif> 3.6.2-1.mga8
+ Revision: 1416212
- New version 3.6.2

* Wed Sep 12 2018 shlomif <shlomif> 3.6.1-1.mga7
+ Revision: 1258685
- New version 3.6.1

* Thu Aug 24 2017 ovitters <ovitters> 3.6.0-1.mga7
+ Revision: 1145251
+ rebuild (emptylog)

* Sat Mar 05 2016 shlomif <shlomif> 3.6.0-1.mga6
+ Revision: 986121
- Correct dep
- Importing nethack-3.6.0 based on the fedora package (thanks)

